@@ -36,9 +36,10 @@ G_DEFINE_TYPE (AVMetaReader, av_meta_reader, G_TYPE_OBJECT)
 gboolean
 av_meta_reader_read (AVMetaReader *reader,
                      DmapAvRecord *record,
-                     const gchar *path)
+                     const gchar *path,
+                     GError **error)
 {
-	return AV_META_READER_GET_CLASS (reader)->read (reader, record, path);
+	return AV_META_READER_GET_CLASS (reader)->read (reader, record, path, error);
 }
 
 GOptionGroup *
