@@ -507,8 +507,6 @@ av_render_gst_class_init (AVRenderGstClass *klass)
 	GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
 	AVRenderClass *av_render_class = AV_RENDER_CLASS (klass);
 
-	g_type_class_add_private (klass, sizeof (AVRenderGstPrivate));
-
 	gobject_class->set_property = _set_property;
 	gobject_class->get_property = _get_property;
 	gobject_class->finalize = _finalize;
@@ -557,4 +555,8 @@ av_render_gst_class_init (AVRenderGstClass *klass)
 							    G_PARAM_READWRITE));
 }
 
-G_DEFINE_DYNAMIC_TYPE (AVRenderGst, av_render_gst, TYPE_AV_RENDER)
+G_DEFINE_DYNAMIC_TYPE_EXTENDED (AVRenderGst,
+                                av_render_gst,
+                                TYPE_AV_RENDER,
+                                0,
+                                G_ADD_PRIVATE_DYNAMIC (AVRenderGst))
