@@ -19,8 +19,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef __AV_RENDER_GST
-#define __AV_RENDER_GST
+#ifndef _AV_RENDER_GST_H
+#define _AV_RENDER_GST_H
 
 #include <libdmapsharing/dmap.h>
 
@@ -66,17 +66,8 @@ typedef struct _AVRenderGstClass {
 
 GType       av_render_gst_get_type      (void);
 
-DmapAvRecord *dacp_player_now_playing_record (DmapControlPlayer * player);
-guchar *dacp_player_now_playing_artwork (DmapControlPlayer * player,
-					       guint width, guint height);
-void dacp_player_play_pause (DmapControlPlayer * player);
-void dacp_player_pause (DmapControlPlayer * player);
-void dacp_player_next_item (DmapControlPlayer * player);
-void dacp_player_prev_item (DmapControlPlayer * player);
-void dacp_player_cue_clear (DmapControlPlayer * player);
-void dacp_player_cue_play (DmapControlPlayer * player, GList * records, guint index);
 GOptionGroup *av_render_gst_get_option_group (AVRender *render);
 
-#endif /* __AV_RENDER_GST */
-
 G_END_DECLS
+
+#endif
