@@ -171,13 +171,13 @@ _file_changed_cb (GFileMonitor *monitor,
 
 	gchar *path = g_file_get_path (file);
 	if (NULL == path) {
-		g_warning ("Could not determine path for changed file\n");
+		g_warning ("Could not determine path for changed file");
 		goto done;
 	}
 
 	switch (event_type) {
 		case G_FILE_MONITOR_EVENT_CREATED:
-			g_debug ("New file: %s\n", path);
+			g_debug ("New file: %s", path);
 
 			ok = _handle_path (builder, path, NULL, &error);
 			if (!ok) {
@@ -188,7 +188,7 @@ _file_changed_cb (GFileMonitor *monitor,
 			break;
 		case G_FILE_MONITOR_EVENT_DELETED:
 			// FIXME: Not implemented, need remove function in database.
-			g_debug ("Removed file: %s\n", path);
+			g_debug ("Removed file: %s", path);
 			g_warning ("Removing file %s not implemented", path);
 			break;
 		default:
@@ -219,12 +219,12 @@ _monitor_directory (DbBuilderGDir *builder, const char *path)
 	GError *error = NULL;
         GFileMonitor *monitor = g_file_monitor_directory (dir, 0, NULL, &error);
         if (NULL == monitor) {
-                g_warning ("Unable to monitor %s: %s\n", path, error->message);
+                g_warning ("Unable to monitor %s: %s", path, error->message);
 		goto done;
         }
 
 	gchar *file = g_file_get_basename (dir);
-	g_debug ("Monitoring %s\n", file);
+	g_debug ("Monitoring %s", file);
 	g_free (file);
 
         g_signal_connect (monitor, "changed", (GCallback) _file_changed_cb, builder);	
@@ -268,7 +268,11 @@ _build_db_starting_at(DbBuilder *builder,
 		g_free (path);
 
 		if (!ok) {
-			goto done;
+			g_warning("%s", (*error)->message);
+
+			/* Failure to load one media file not fatal. */
+			g_clear_error(error);
+			ok = TRUE;
 		}
 	}
 
@@ -335,8 +339,6 @@ static void db_builder_gdir_class_init (DbBuilderGDirClass *klass)
                                                               "Container DB object",
 	                                                       DMAP_TYPE_CONTAINER_DB,
                                                                G_PARAM_READWRITE));
-
-	g_type_class_add_private (klass, sizeof (DbBuilderGDir));
 }
 
 static void db_builder_gdir_register_type (GTypeModule *module);
@@ -353,4 +355,8 @@ dmapd_module_unload (GTypeModule *module)
 {
 }
 
-G_DEFINE_DYNAMIC_TYPE (DbBuilderGDir, db_builder_gdir, TYPE_DB_BUILDER)
+G_DEFINE_DYNAMIC_TYPE_EXTENDED (DbBuilderGDir,
+                                db_builder_gdir,
+                                TYPE_DB_BUILDER,
+                                0,
+                                G_ADD_PRIVATE_DYNAMIC (DbBuilderGDir))
