@@ -372,14 +372,14 @@ _set_from_blob (DmapRecord *_record, GArray *blob)
 
 	size = *((guint *) ptr);
 	if (DMAP_HASH_SIZE != size) {
-                g_warning ("Improper hash size in cache\n");
+                g_warning ("Improper hash size in cache");
                 goto _done;
         }
         ptr += sizeof (size);
 
         hash = g_array_sized_new (FALSE, FALSE, 1, size);
 	if (NULL == hash) {
-		g_warning ("Error allocating array for hash\n");
+		g_warning ("Error allocating array for hash");
 		goto _done;
 	}
         g_array_append_vals (hash, ptr, size);
@@ -434,26 +434,26 @@ _set_from_blob (DmapRecord *_record, GArray *blob)
 
 	file = g_file_new_for_uri (location);
         if (NULL == location) {
-                g_warning ("Could not open %s\n", location);
+                g_warning ("Could not open %s", location);
                 goto _done;
         }	
 
 	stream = g_file_read (file, NULL, &error);
 	if (NULL == stream) {
-                g_warning ("Could not read %s: %s\n", location, error->message);
+                g_warning ("Could not read %s: %s", location, error->message);
                 goto _done;
 	}
 
 	if (FALSE /* FIXME: calculate_media_hashes */) {
 		if (! util_hash_file (location, hash2)
 		 || memcmp (hash->data, hash2, DMAP_HASH_SIZE)) {
-			g_warning ("Media file hash has changed since being cached\n");
+			g_warning ("Media file hash has changed since being cached");
 			goto _done;
 		}
 	} else {
 		path = g_file_get_path(file);
 		if (NULL == path) {
-			g_warning ("Could not convert %s to local path; assuming modified\n", location);
+			g_warning ("Could not convert %s to local path; assuming modified", location);
 			goto _done;
 		}
 		if (stat (path, &buf) == -1) {
@@ -461,7 +461,7 @@ _set_from_blob (DmapRecord *_record, GArray *blob)
 			goto _done;
 		} else {
 			if (buf.st_mtime > mtime) {
-				g_warning ("Media file mtime has changed since being cached\n");
+				g_warning ("Media file mtime has changed since being cached");
 				goto _done;
 			}
 		}
@@ -524,8 +524,6 @@ dmapd_daap_record_class_init (DmapdDmapAvRecordClass *klass)
 {
 	GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
 
-	g_type_class_add_private (klass, sizeof (DmapdDmapAvRecordPrivate));
-
 	gobject_class->set_property = _set_property;
 	gobject_class->get_property = _get_property;
 	gobject_class->finalize     = _finalize;
@@ -577,7 +575,8 @@ _dmap_record_iface_init (gpointer iface, gpointer data)
 
 G_DEFINE_TYPE_WITH_CODE (DmapdDmapAvRecord, dmapd_daap_record, G_TYPE_OBJECT, 
 			 G_IMPLEMENT_INTERFACE (DMAP_TYPE_AV_RECORD, _dmap_av_record_iface_init)
-			 G_IMPLEMENT_INTERFACE (DMAP_TYPE_RECORD, _dmap_record_iface_init))
+			 G_IMPLEMENT_INTERFACE (DMAP_TYPE_RECORD, _dmap_record_iface_init)
+                         G_ADD_PRIVATE (DmapdDmapAvRecord))
 
 static void
 _finalize (GObject *object)
@@ -598,7 +597,7 @@ _finalize (GObject *object)
 }
 
 DmapdDmapAvRecord *
-dmapd_daap_record_new (const char *path, AVMetaReader *reader)
+dmapd_daap_record_new (const char *path, AVMetaReader *reader, GError **error)
 {
 	DmapdDmapAvRecord *record = NULL;
 	guchar hash_buf[DMAP_HASH_SIZE];
@@ -608,27 +607,20 @@ dmapd_daap_record_new (const char *path, AVMetaReader *reader)
 	GArray *hash = NULL;
 
 	if (path) {
-		location = g_filename_to_uri (path, NULL, NULL);
+		location = g_filename_to_uri (path, NULL, error);
 		if (NULL == location) {
-			g_warning ("Error converting %s to URI\n", path);
 			goto _done;
 		}
 
 		title = g_path_get_basename (path);
-		if (NULL == title) {
-			g_warning ("Error extracting filename from %s\n", path);
-			goto _done;
-		}
-
 		hash = g_array_sized_new (FALSE, FALSE, 1, DMAP_HASH_SIZE);
-		if (NULL == hash) {
-			g_warning ("Error allocating memory for record's hash field\n");
-			goto _done;
-		}
 
 		if (FALSE /* FIXME: calculate_media_hashes */) {
 			if (! util_hash_file (location, hash_buf)) {
-				g_warning ("Unable to hash %s\n", location);
+				g_set_error(error,
+				            DMAP_ERROR,
+				            DMAP_STATUS_FAILED,
+				           "Unable to hash %s", location);
 				goto _done;
 			}
 		} else {
@@ -638,10 +630,6 @@ dmapd_daap_record_new (const char *path, AVMetaReader *reader)
 		g_array_append_vals (hash, hash_buf, DMAP_HASH_SIZE);
 
 		record = DMAPD_DMAP_AV_RECORD (g_object_new (TYPE_DMAPD_DMAP_AV_RECORD, NULL));
-		if (NULL == record) {
-			g_warning ("Error allocating memory for record\n");
-			goto _done;
-		}
 
 		if (stat (path, &buf) == -1) {
 			g_warning ("Unable to determine size of %s", path);
@@ -666,7 +654,10 @@ dmapd_daap_record_new (const char *path, AVMetaReader *reader)
 		                      "disc",        1,
 		                       NULL);
 
-		if (! av_meta_reader_read (AV_META_READER (reader), DMAP_AV_RECORD (record), path)) {
+		if (! av_meta_reader_read (AV_META_READER (reader),
+		                           DMAP_AV_RECORD (record),
+		                           path,
+		                           error)) {
 			g_object_unref (record);
 			record = NULL;
 			goto _done;
@@ -677,21 +668,12 @@ dmapd_daap_record_new (const char *path, AVMetaReader *reader)
 		record->priv->bitrate = 128;	/* FIXME, from codec decoder */
 	} else {
 		record = DMAPD_DMAP_AV_RECORD (g_object_new (TYPE_DMAPD_DMAP_AV_RECORD, NULL));
-		if (NULL == record) {
-			g_warning ("Error allocating memory for record");
-			goto _done;
-		}
 	}
 
 _done:
 
-	if (NULL != location) {
-		g_free (location);
-	}
-
-	if (NULL != title) {
-		g_free (title);
-	}
+	g_free (location);
+	g_free (title);
 
 	if (NULL != hash) {
 		g_array_unref (hash);
