@@ -54,11 +54,12 @@ typedef struct {
 typedef struct {
 	GObjectClass parent;
 
-	guint (*add)                   (DmapDb *db, DmapRecord *record);
+	guint (*add)                   (DmapDb *db, DmapRecord *record, GError **error);
 	guint (*add_with_id)           (DmapDb *db,
 					DmapRecord *record,
-					guint id);
-	guint (*add_path)              (DmapDb *db, const gchar *path);
+					guint id,
+	                                GError **error);
+	guint (*add_path)              (DmapDb *db, const gchar *path, GError **error);
 	DmapRecord *(*lookup_by_id)    (const DmapDb *db, guint id);
 	guint (*lookup_id_by_location) (const DmapDb *db,
 					const gchar *location);
