@@ -37,25 +37,25 @@ enum {
 	DPAP
 };
 
-static GMainLoop *loop;
+static GMainLoop *_loop;
 
-static gchar *_service_name = NULL;
-static guint iteration_count = ~0;
+static gchar *_service_name    = NULL;
+static guint  _iteration_count = ~0;
 
-static GOptionEntry entries[] = {
+static GOptionEntry _entries[] = {
         { "service-name", 's', 0, G_OPTION_ARG_STRING, &_service_name, "Server name to connect to; default is to query user interactively", NULL },
-        { "iteration-count", 'i', 0, G_OPTION_ARG_INT, &iteration_count, "Number of times to hit server; default is forever", NULL },
+        { "iteration-count", 'i', 0, G_OPTION_ARG_INT, &_iteration_count, "Number of times to hit server; default is forever", NULL },
 	{ NULL }
 };
 
 static void
-create_connection (const DmapMdnsServiceType protocol,
-		   const char *name,
-		   const char *host,
-		   const guint port);
+_create_connection (const DmapMdnsServiceType protocol,
+                    const char *name,
+                    const char *host,
+                    const guint port);
 
 static void
-process_record (gpointer id, DmapRecord *record, gpointer user_data)
+_process_record (gpointer id, DmapRecord *record, gpointer user_data)
 {
 	guint status;
 	SoupSession *soup_session;
@@ -113,31 +113,35 @@ process_record (gpointer id, DmapRecord *record, gpointer user_data)
 }
 
 static DmapMdnsServiceType
-get_service_type (DmapConnection *connection)
+_get_service_type (DmapConnection *connection)
 {
+	DmapMdnsServiceType type;
+
 	if (IS_DMAP_AV_CONNECTION (connection)) {
-		return DMAP_MDNS_SERVICE_TYPE_DAAP;
+		type = DMAP_MDNS_SERVICE_TYPE_DAAP;
 	} else if (IS_DMAP_IMAGE_CONNECTION (connection)) {
-		return DMAP_MDNS_SERVICE_TYPE_DPAP;
+		type = DMAP_MDNS_SERVICE_TYPE_DPAP;
 	} else {
 		g_error ("Bad connection");
 	}
+
+	return type;
 }
 
 static void
-connected_cb (DmapConnection *connection,
-	      gboolean        result,
-	      const char     *reason,
-	      DmapDb         *db)
+_connected_cb (DmapConnection *connection,
+               gboolean        result,
+               const char     *reason,
+               DmapDb         *db)
 {
 	guint port;
 	char *name, *host;
-	static guint count = 1; // This counts up, iteration_count goes down.
+	static guint count = 1; // This counts up, _iteration_count goes down.
 
 	g_print ("Connection cb., DB has %lu entries\n", dmap_db_count (db));
 	g_print ("Iteration %d...\n", count++);
 
-	dmap_db_foreach (db, (DmapIdRecordFunc) process_record, NULL);
+	dmap_db_foreach (db, (DmapIdRecordFunc) _process_record, NULL);
 
 	g_object_get (connection,
 		     "name", &name,
@@ -148,14 +152,14 @@ connected_cb (DmapConnection *connection,
 	/* Tear down connection. */
 	g_object_unref (connection);
 
-	if (--iteration_count > 0) {
+	if (--_iteration_count > 0) {
 		/* Create another connection to same service. */
-		create_connection (get_service_type (connection),
+		_create_connection (_get_service_type (connection),
 				   name,
 				   host,
 				   port);
 	} else {
-		g_main_loop_quit (loop);
+		g_main_loop_quit (_loop);
 	}
 
 	g_free (name);
@@ -163,10 +167,10 @@ connected_cb (DmapConnection *connection,
 }
 
 static void
-create_connection (const DmapMdnsServiceType protocol,
-		   const char *name,
-		   const char *host,
-		   const guint port)
+_create_connection (const DmapMdnsServiceType protocol,
+                    const char *name,
+                    const char *host,
+                    const guint port)
 {
 	DmapRecordFactory *factory;
 	DmapConnection *conn;
@@ -179,7 +183,7 @@ create_connection (const DmapMdnsServiceType protocol,
 
 	/* FIXME: switch on DMAP_MDNS_SERVICE_TYPE_DAAP, _DPAP, _DACP or _INVALID */
 	if (protocol == DMAP_MDNS_SERVICE_TYPE_DAAP) {
-		factory = DMAP_RECORD_FACTORY (g_object_new (TYPE_DMAPD_DMAP_AV_RECORD_FACTORY, NULL));
+		factory = DMAP_RECORD_FACTORY (g_object_new (TYPE_DMAPD_DMAP_RECORD_FACTORY, NULL));
 		if (factory == NULL) {
 			g_error ("Error creating record factory");
 		}
@@ -191,13 +195,13 @@ create_connection (const DmapMdnsServiceType protocol,
 		}
 		conn = DMAP_CONNECTION (dmap_image_connection_new (name, host, port, db, factory));
 	}
-	dmap_connection_start (DMAP_CONNECTION (conn), (DmapConnectionFunc) connected_cb, db);
+	dmap_connection_start (DMAP_CONNECTION (conn), (DmapConnectionFunc) _connected_cb, db);
 }
 
 static void
-service_added_cb (DmapMdnsBrowser *browser,
-                  DmapMdnsService *service,
-                  gpointer user_data)
+_service_added_cb (DmapMdnsBrowser *browser,
+                   DmapMdnsService *service,
+                   gpointer user_data)
 {
 	char answer, newline;
 
@@ -227,7 +231,7 @@ service_added_cb (DmapMdnsBrowser *browser,
 	}
 
 	if (answer == 'Y') {
-		create_connection (dmap_mdns_browser_get_service_type (browser),
+		_create_connection (dmap_mdns_browser_get_service_type (browser),
 				   name,
 				   host,
 				   port);
@@ -235,45 +239,46 @@ service_added_cb (DmapMdnsBrowser *browser,
 }
 
 static void
-debug_null (const char *log_domain,
-            GLogLevelFlags log_level,
-	    const gchar *message,
-	    gpointer user_data)
+_debug_null (const char *log_domain,
+             GLogLevelFlags log_level,
+             const gchar *message,
+             gpointer user_data)
 {
 }
 
-int main(int argc, char **argv)
+int
+main(int argc, char **argv)
 {
 	GOptionContext *context;
 	DmapMdnsBrowser *browserDAAP, *browserDPAP;
 	GError *error = NULL;
 
-	stringleton_init ();
+	util_stringleton_init ();
 
-	g_log_set_handler ("libdmapsharing", G_LOG_LEVEL_DEBUG, debug_null, NULL);
-	g_log_set_handler (NULL, G_LOG_LEVEL_DEBUG, debug_null, NULL);
+	g_log_set_handler ("libdmapsharing", G_LOG_LEVEL_DEBUG, _debug_null, NULL);
+	g_log_set_handler (NULL, G_LOG_LEVEL_DEBUG, _debug_null, NULL);
 
 	context = g_option_context_new ("Stress test dmapd");
-        g_option_context_add_main_entries (context, entries, NULL);
+        g_option_context_add_main_entries (context, _entries, NULL);
 
 	if (! g_option_context_parse (context, &argc, &argv, &error)) {
                 g_error ("Option parsing failed: %s", error->message);
         }
 
-	loop = g_main_loop_new (NULL, FALSE);
+	_loop = g_main_loop_new (NULL, FALSE);
 
 	browserDAAP = dmap_mdns_browser_new (DMAP_MDNS_SERVICE_TYPE_DAAP);
 
 	g_signal_connect (G_OBJECT (browserDAAP),
 		         "service-added",
-		          G_CALLBACK (service_added_cb),
+		          G_CALLBACK (_service_added_cb),
 		          NULL);
 
 	browserDPAP = dmap_mdns_browser_new (DMAP_MDNS_SERVICE_TYPE_DPAP);
 
 	g_signal_connect (G_OBJECT (browserDPAP),
 		         "service-added",
-		          G_CALLBACK (service_added_cb),
+		          G_CALLBACK (_service_added_cb),
 		          NULL);
 
 	g_debug ("starting mdns browsers");
@@ -295,7 +300,7 @@ int main(int argc, char **argv)
 	}
 
 	fprintf (stdout, "Waiting for DMAP shares; please run dmapd.\n");
-	g_main_loop_run (loop);
+	g_main_loop_run (_loop);
 
 	fprintf (stdout, "Stress test complete.\n");
 
