@@ -41,7 +41,7 @@ _get_option_group (PhotoMetaReader * reader)
 	g_assert (IS_PHOTO_META_READER (reader));
 
 	if (0 != vips_init ("dmapd")) {
-		g_error ("Could not initialize VIPS\n");
+		g_error ("Could not initialize VIPS");
 	}
 
 	/* VIPS caches operations, but this ends up in a lot of open file descriptors.
@@ -158,25 +158,25 @@ _get_thumbnail (PhotoMetaReader *reader, VipsImage *im)
 	g_assert (VIPS_IS_IMAGE (im));
 
 	if (! vips_image_get_typeof (im, THUMBNAIL)) {
-		g_debug ("    No embedded JPEG thumbnail found."); 
+		g_debug ("    No embedded JPEG thumbnail found.");
 		goto _done;
 	}
 
 	if (vips_image_get_blob (im, THUMBNAIL, &ptr, &size)) {
-		g_warning ("    Loading embedded JPEG thumbnail failed.\n"); 
+		g_warning ("    Loading embedded JPEG thumbnail failed");
 		goto _done;
 	}
 
 	if (vips_jpegload_buffer (ptr, size, &thumb, NULL)) {
-		g_warning ("    Decoding embedded JPEG thumbnail failed.\n"); 
+		g_warning ("    Decoding embedded JPEG thumbnail failed");
 		goto _done;
 	}
 	g_debug ("    Embedded JPEG thumbnail size is %zd.", size);
 
 	(void) _calculate_shrink (reader, thumb->Xsize, thumb->Ysize, &residual);
 	if (residual > 1.0) { 
-		g_warning ("    Embedded JPEG thumbnail too small.\n"); 
-		g_object_unref (thumb); 
+		g_warning ("    Embedded JPEG thumbnail too small");
+		g_object_unref (thumb);
 		thumb = NULL;
 		goto _done;
 	}
@@ -188,7 +188,7 @@ _get_thumbnail (PhotoMetaReader *reader, VipsImage *im)
 	g_object_unref (thumb);
 	thumb = NULL;
 	if( vips_jpegload_buffer (ptr, size, &thumb, "shrink", jpegshrink, NULL)) {
-		g_warning ("   Reloading embedded JPEG thumbnail failed.\n"); 
+		g_warning ("   Reloading embedded JPEG thumbnail failed");
 		goto _done;
 	}
 	g_debug ("    Embedded JPEG thumbnail size is %zd.", size);
@@ -218,11 +218,11 @@ _thumbnail_open (PhotoMetaReader *reader, VipsObject *process, const char *filen
 
 	loader = vips_foreign_find_load (filename);
 	if (NULL == loader) {
-		g_warning ("    No image loader found.\n");
+		g_warning ("    No image loader found");
 		goto _done;
 	}
 
-	g_debug ("    Selected image loader is %s.", loader); 
+	g_debug ("    Selected image loader is %s.", loader);
 
 	if (0 == strcmp (loader, "VipsForeignLoadJpegFile")) {
 		VipsImage *thumb = NULL;
@@ -230,7 +230,7 @@ _thumbnail_open (PhotoMetaReader *reader, VipsObject *process, const char *filen
 		/* This will just read in the header and is quick. */
 		im = vips_image_new_from_file (filename, NULL);
 		if (NULL == im) {
-			g_warning ("    Error reading header from %s.\n", filename);
+			g_warning ("    Error reading header from %s", filename);
 			goto _done;
 		}
 		vips_object_local (process, im);
@@ -240,7 +240,7 @@ _thumbnail_open (PhotoMetaReader *reader, VipsObject *process, const char *filen
 		if (NULL != thumb) {
 			vips_object_local (process, thumb);
 
-			g_debug ("    Using %dx%d embedded JPEG thumbnail.", thumb->Xsize, thumb->Ysize); 
+			g_debug ("    Using %dx%d embedded JPEG thumbnail.", thumb->Xsize, thumb->Ysize);
 
 			/* @thumb has not been fully decoded yet ... 
 			 * we must not close @im until we're done with @thumb.
@@ -267,7 +267,7 @@ _thumbnail_open (PhotoMetaReader *reader, VipsObject *process, const char *filen
 			                      "access", VIPS_ACCESS_SEQUENTIAL,
 			                      "shrink", jpegshrink,
 			                       NULL)) {
-				g_warning ("    Could not load %s.\n", im->filename);
+				g_warning ("    Could not load %s", im->filename);
 				goto _done;
 			}
 			vips_object_local (process, im);
@@ -285,7 +285,7 @@ _thumbnail_open (PhotoMetaReader *reader, VipsObject *process, const char *filen
 	}
 
 _done:
-	return im; 
+	return im;
 }
 
 static gboolean
@@ -297,9 +297,9 @@ _thumbnail_shrink (PhotoMetaReader *reader, VipsObject *process, VipsImage *in,
 	g_assert (NULL != thumb);
 	g_assert (NULL != size);
 
-	int shrink; 
+	int shrink;
 	int nlines;
-	double residual; 
+	double residual;
 	VipsInterpolate *interp;
 	gboolean fnval = FALSE;
 	int tile_width;
@@ -309,7 +309,7 @@ _thumbnail_shrink (PhotoMetaReader *reader, VipsObject *process, VipsImage *in,
 
 	/* Unpack the two coded formats we support. */
 	if (in->Coding == VIPS_CODING_LABQ) {
-		g_debug ("    Unpacking LAB to RGB.\n");
+		g_debug ("    Unpacking LAB to RGB");
 
 		if (vips_colourspace(in, &t[0], VIPS_INTERPRETATION_sRGB, NULL)) {
 			goto _done;
@@ -318,7 +318,7 @@ _thumbnail_shrink (PhotoMetaReader *reader, VipsObject *process, VipsImage *in,
 		in = t[0];
 	}
 	else if (in->Coding == IM_CODING_RAD) {
-		g_debug ("    Unpacking Rad to float.\n");
+		g_debug ("    Unpacking Rad to float");
 
 		/* rad is scrgb. */
 		if (vips_rad2float (in, &t[0], NULL) ||
@@ -360,7 +360,7 @@ _thumbnail_shrink (PhotoMetaReader *reader, VipsObject *process, VipsImage *in,
 	    vips_affine    (t[3], &t[4], residual, 0, 0, residual, NULL, 
 	                   "interpolate", interp,
 	                    NULL)) {
-		g_warning ("    Could not get tile size.\n");
+		g_warning ("    Could not get tile size");
 		goto _done;
 	}
 	in = t[4];
@@ -395,11 +395,11 @@ _get_str (VipsImage *im, const char *field)
 	}
 
 done:
-	return str; 
+	return str;
 }
 
 static gboolean
-_read (PhotoMetaReader *reader, DmapImageRecord *record, const gchar *path)
+_read (PhotoMetaReader *reader, DmapImageRecord *record, const gchar *path, GError **error)
 {
 	g_assert (IS_PHOTO_META_READER (reader));
 	g_assert (IS_DMAP_IMAGE_RECORD (record));
@@ -421,19 +421,25 @@ _read (PhotoMetaReader *reader, DmapImageRecord *record, const gchar *path)
 	/* Allocate all vips objects locally to this ... unref this to unref 
 	 * everything we created during this operation.
 	 */
-	process = (VipsObject *) vips_image_new (); 
+	process = (VipsObject *) vips_image_new ();
 
 	g_debug ("Processing %s...", path);
 
 	format = vips_format_for_file (path);
         if (NULL == format) {
-                g_warning ("Do not know how to handle %s.", path);
+		g_set_error(error,
+		            DMAP_ERROR,
+		            DMAP_STATUS_FAILED,
+		           "Do not know how to handle %s", path);
                 goto _done;
         }
 
 	im = vips_image_new_from_file (path, NULL);
 	if (NULL == im) {
-		g_warning ("Could not open %s", path);
+		g_set_error(error,
+		            DMAP_ERROR,
+		            DMAP_STATUS_FAILED,
+		           "Could not open %s", path);
 		goto _done;
 	}
 	vips_object_local (process, im);
@@ -446,12 +452,8 @@ _read (PhotoMetaReader *reader, DmapImageRecord *record, const gchar *path)
 	}
 
 	basename = g_path_get_basename (path);
-	if (NULL == basename) {
-		g_warning ("Unable to determine basename of %s\n", path);
-	} else {
-		g_debug ("    Tag filename is %s.", basename);
-		g_object_set (record, "filename", basename, NULL);
-	}
+	g_debug ("    Tag filename is %s.", basename);
+	g_object_set (record, "filename", basename, NULL);
 
 	g_object_set (record, "format", VIPS_OBJECT_CLASS (format)->nickname, NULL);
 	g_object_set (record, "pixel-height", im->Ysize, NULL);
@@ -465,7 +467,7 @@ _read (PhotoMetaReader *reader, DmapImageRecord *record, const gchar *path)
 
 	aspect_ratio = g_strdup_printf ("%f", im->Xsize / (float) im->Ysize);
 	if (NULL == aspect_ratio) {
-		g_warning ("Could not set aspect ratio\n");
+		g_warning ("Could not set aspect ratio");
 	} else {
 		g_debug ("    Tag aspect ratio is %s.", aspect_ratio);
 		g_object_set (record, "aspect-ratio", aspect_ratio, NULL);
@@ -500,7 +502,10 @@ _read (PhotoMetaReader *reader, DmapImageRecord *record, const gchar *path)
 
 	thumb = _thumbnail_open (reader, process, path);
 	if (NULL == thumb) {
-		g_warning ("Could not open thumbnail for %s", path);
+		g_set_error(error,
+		            DMAP_ERROR,
+		            DMAP_STATUS_FAILED,
+		           "Could not open thumbnail for %s", path);
 		goto _done;
 	}
 
@@ -510,7 +515,7 @@ _read (PhotoMetaReader *reader, DmapImageRecord *record, const gchar *path)
 		if (NULL == thumbnail_array) {
 			// FIXME: I think the thumbnail prop. MUST be non-NULL;
 			//        if not, this could be cleaned up and non-fatal.
-			g_error ("Could not allocate memory for thumbnail array\n");
+			g_error ("Could not allocate memory for thumbnail array");
 		} else {
 			g_array_append_vals (thumbnail_array, thumbnail_data, thumbnail_size);
 		}
@@ -519,7 +524,7 @@ _read (PhotoMetaReader *reader, DmapImageRecord *record, const gchar *path)
 		if (NULL == thumbnail_array) {
 			// FIXME: I think the thumbnail prop. MUST be non-NULL;
 			//        if not, this could be cleaned up and non-fatal.
-			g_error ("Could not allocate memory for empty thumbnail array\n");
+			g_error ("Could not allocate memory for empty thumbnail array");
 		}
 	}
 	g_object_set (record, "thumbnail", thumbnail_array, NULL);
@@ -531,17 +536,9 @@ _done:
 		g_object_unref (process);
 	}
 
-	if (NULL != basename) {
-		g_free (basename);
-	}	
-
-	if (NULL != aspect_ratio) {
-		g_free (aspect_ratio);
-	}	
-
-	if (NULL != thumbnail_data) {
-		g_free (thumbnail_data);
-	}
+	g_free (basename);
+	g_free (aspect_ratio);
+	g_free (thumbnail_data);
 
 	if (NULL != thumbnail_array) {
 		g_array_unref (thumbnail_array);
@@ -567,8 +564,6 @@ photo_meta_reader_vips_class_init (PhotoMetaReaderVipsClass * klass)
 	PhotoMetaReaderClass *photo_meta_reader =
 		PHOTO_META_READER_CLASS (klass);
 
-	/* g_type_class_add_private (klass, sizeof (PhotoMetaReaderVipsPrivate)); */
-
 	photo_meta_reader->read = _read;
 	photo_meta_reader->get_option_group = _get_option_group;
 }
