@@ -20,8 +20,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef __DMAPD_UTIL
-#define __DMAPD_UTIL
+#ifndef _UTIL_H
+#define _UTIL_H
 
 #include <libdmapsharing/dmap.h>
 #include <glib.h>
@@ -33,32 +33,32 @@ typedef enum {
 	CACHE_TYPE_THUMBNAIL_DATA
 } cache_type_t;
 
-gchar *parse_plugin_option (gchar *str, GHashTable *hash_table);
+gchar *util_parse_plugin_option (gchar *str, GHashTable *hash_table);
 
-GArray *blob_add_atomic (GArray *blob,
-			 const guint8 *ptr,
-			 const size_t size);
+GArray *util_blob_add_atomic (GArray *blob,
+                              const guint8 *ptr,
+                              const size_t size);
 
-GArray *blob_add_string (GArray *blob, const gchar *str);
+GArray *util_blob_add_string (GArray *blob, const gchar *str);
 
-void stringleton_init (void);
+void util_stringleton_init (void);
 
-const gchar *stringleton_ref (const gchar *str);
+const gchar *util_stringleton_ref (const gchar *str);
 
-void stringleton_unref (const gchar *str);
+void util_stringleton_unref (const gchar *str);
 
-void stringleton_deinit (void);
+void util_stringleton_deinit (void);
 
-GObject *object_from_module (GType type,
-                             const gchar *module_dir,
-                             const gchar *module_name,
-                             const gchar *first_property_name,
-                             ...);
+GObject *util_object_from_module (GType type,
+                                  const gchar *module_dir,
+                                  const gchar *module_name,
+                                  const gchar *first_property_name,
+                                  ...);
 
-gchar *cache_path (cache_type_t type, const gchar *db_dir, const gchar *imagepath);
+gchar *util_cache_path (cache_type_t type, const gchar *db_dir, const gchar *imagepath);
 
-void cache_store (const gchar *db_dir, const gchar *uri, GArray *blob);
+void util_cache_store (const gchar *db_dir, const gchar *uri, GArray *blob);
 
-gboolean dmapd_util_hash_file (const gchar *uri, unsigned char hash[DMAP_HASH_SIZE]);
+gboolean util_hash_file (const gchar *uri, unsigned char hash[DMAP_HASH_SIZE]);
 
 #endif
